@@ -663,9 +663,13 @@ void ZAM_OpTemplate::InstantiateAssignOp(const vector<ZAM_OperandType>& ot, cons
 		Emit("case " + op + ":");
 		BeginBlock();
 		GenAssignOpCore(ot, eval, ti.accessor, ti.is_managed);
+		if ( ! post_eval.empty() )
+			Emit(post_eval);
 		Emit("break;");
 		EndBlock();
 		}
+
+	post_eval.clear();
 	}
 
 void ZAM_OpTemplate::GenAssignOpCore(const vector<ZAM_OperandType>& ot, const string& eval,
@@ -1680,7 +1684,12 @@ void ZAM_RelationalExprOpTemplate::BuildInstruction(const vector<ZAM_OperandType
 			op1 = "n1";
 		}
 	else
-		op1 = "n2";
+		{
+		if ( ot[1] == ZAM_OT_CONSTANT )
+			op1 = "c";
+		else
+			op1 = "n2";
+		}
 
 	auto type_suffix = zc == ZIC_VEC ? "->Yield();" : ";";
 	Emit("auto t = " + op1 + "->GetType()" + type_suffix);
@@ -1785,7 +1794,7 @@ void ZAM_InternalOpTemplate::Parse(const string& attr, const string& line, const
 	auto arg_offset = HasAssignVal() ? 1 : 0;
 	auto arg_slot = arg_offset + 1;
 
-	string func = "z.func";
+	string func = "z.aux->func";
 
 	if ( n == 1 )
 		{
@@ -1841,16 +1850,24 @@ void ZAM_InternalOpTemplate::Parse(const string& attr, const string& line, const
 				}
 		}
 
-	eval += "f->SetOnlyCall(z.call_expr.get());\n";
+	eval += "f->SetOnlyCall(z.aux->call_expr.get());\n";
+	eval += "ZAM_PROFILE_PRE_CALL\n";
 
 	if ( HasAssignVal() )
 		{
 		auto av = GetAssignVal();
 		eval += "auto " + av + " = " + func + "->Invoke(&args, f);\n";
 		eval += "if ( ! " + av + " ) { ZAM_error = true; break; }\n";
+
+		// Postpone the profiling follow-up until after we process
+		// the assignment.
+		post_eval = "ZAM_PROFILE_POST_CALL\n";
 		}
 	else
+		{
 		eval += "(void) " + func + "->Invoke(&args, f);\n";
+		eval += "ZAM_PROFILE_POST_CALL\n";
+		}
 	}
 
 bool TemplateInput::ScanLine(string& line)
@@ -1942,30 +1959,37 @@ void TemplateInput::Gripe(const char* msg, const InputLoc& l) const
 
 ZAMGen::ZAMGen(int argc, char** argv)
 	{
-	auto prog_name = argv[0];
+	auto prog_name = (argv++)[0];
 
-	if ( argc != 2 )
+	if ( --argc < 1 )
 		{
 		fprintf(stderr, "usage: %s <ZAM-templates-file>\n", prog_name);
 		exit(1);
 		}
 
-	auto file_name = argv[1];
-	auto f = strcmp(file_name, "-") ? fopen(file_name, "r") : stdin;
-
-	if ( ! f )
+	while ( argc-- > 0 )
 		{
-		fprintf(stderr, "%s: cannot open \"%s\"\n", prog_name, file_name);
-		exit(1);
+		auto file_name = (argv++)[0];
+		bool is_stdin = file_name == std::string("-");
+		auto f = is_stdin ? stdin : fopen(file_name, "r");
+
+		if ( ! f )
+			{
+			fprintf(stderr, "%s: cannot open \"%s\"\n", prog_name, file_name);
+			exit(1);
+			}
+
+		ti = make_unique<TemplateInput>(f, prog_name, file_name);
+
+		while ( ParseTemplate() )
+			;
+
+		if ( ! is_stdin )
+			fclose(f);
 		}
 
-	ti = make_unique<TemplateInput>(f, prog_name, file_name);
-
 	InitEmitTargets();
 
-	while ( ParseTemplate() )
-		;
-
 	for ( auto& t : templates )
 		t->Instantiate();
 
