@@ -2,12 +2,11 @@
 
 #pragma once
 
-#include <spicy/ast/aliases.h>
 #include <spicy/ast/ctors/all.h>
 #include <spicy/ast/declarations/all.h>
-#include <spicy/ast/engine.h>
-#include <spicy/ast/expressions/all.h>
-#include <spicy/ast/hook.h>
+#include <spicy/ast/forward.h>
+#include <spicy/ast/node-tag.h>
 #include <spicy/ast/operators/all.h>
 #include <spicy/ast/statements/all.h>
 #include <spicy/ast/types/all.h>
+#include <spicy/ast/visitor.h>
