@@ -39,10 +39,6 @@ void CPPCompile::GenStmt(const Stmt* s) {
 
         case STMT_RETURN: GenReturnStmt(s->AsReturnStmt()); break;
 
-        case STMT_ADD: GenAddStmt(static_cast<const ExprStmt*>(s)); break;
-
-        case STMT_DELETE: GenDeleteStmt(static_cast<const ExprStmt*>(s)); break;
-
         case STMT_EVENT: GenEventStmt(static_cast<const EventStmt*>(s)); break;
 
         case STMT_SWITCH: GenSwitchStmt(static_cast<const SwitchStmt*>(s)); break;
@@ -149,32 +145,6 @@ void CPPCompile::GenReturnStmt(const ReturnStmt* r) {
     }
 }
 
-void CPPCompile::GenAddStmt(const ExprStmt* es) {
-    auto op = es->StmtExpr();
-    auto aggr = GenExpr(op->GetOp1(), GEN_DONT_CARE);
-    auto indices = op->GetOp2();
-
-    Emit("add_element__CPP(%s, index_val__CPP({%s}));", aggr, GenExpr(indices, GEN_VAL_PTR));
-}
-
-void CPPCompile::GenDeleteStmt(const ExprStmt* es) {
-    auto op = es->StmtExpr();
-    auto aggr = op->GetOp1();
-    auto aggr_gen = GenExpr(aggr, GEN_VAL_PTR);
-
-    if ( op->Tag() == EXPR_INDEX ) {
-        auto indices = op->GetOp2();
-
-        Emit("remove_element__CPP(%s, index_val__CPP({%s}));", aggr_gen, GenExpr(indices, GEN_VAL_PTR));
-    }
-
-    else {
-        ASSERT(op->Tag() == EXPR_FIELD);
-        auto field = GenField(aggr, op->AsFieldExpr()->Field());
-        Emit("%s->Remove(%s);", aggr_gen, field);
-    }
-}
-
 void CPPCompile::GenEventStmt(const EventStmt* ev) {
     auto ev_s = ev->StmtExprPtr();
     auto ev_e = cast_intrusive<EventExpr>(ev_s);
