@@ -12,9 +12,13 @@
 
 namespace zeek::detail {
 
-StmtPtr curr_stmt;
+namespace ZAM {
+std::string curr_func;
+std::shared_ptr<ZAMLocInfo> curr_loc;
 TypePtr log_ID_enum_type;
 TypePtr any_base_type;
+} // namespace ZAM
+
 bool ZAM_error = false;
 
 bool is_ZAM_compilable(const ProfileFunc* pf, const char** reason) {
@@ -77,8 +81,8 @@ void ZAM_run_time_error(const char* msg) {
     ZAM_error = true;
 }
 
-void ZAM_run_time_error(std::shared_ptr<Location> loc, const char* msg) {
-    reporter->RuntimeError(loc.get(), "%s", msg);
+void ZAM_run_time_error(std::shared_ptr<ZAMLocInfo> loc, const char* msg) {
+    reporter->RuntimeError(loc->Loc(), "%s", msg);
     ZAM_error = true;
 }
 
@@ -87,14 +91,14 @@ void ZAM_run_time_error(const char* msg, const Obj* o) {
     ZAM_error = true;
 }
 
-void ZAM_run_time_error(std::shared_ptr<Location> loc, const char* msg, const Obj* o) {
-    reporter->RuntimeError(loc.get(), "%s (%s)", msg, obj_desc(o).c_str());
+void ZAM_run_time_error(std::shared_ptr<ZAMLocInfo> loc, const char* msg, const Obj* o) {
+    reporter->RuntimeError(loc->Loc(), "%s (%s)", msg, obj_desc(o).c_str());
     ZAM_error = true;
 }
 
-void ZAM_run_time_warning(std::shared_ptr<Location> loc, const char* msg) {
+void ZAM_run_time_warning(std::shared_ptr<ZAMLocInfo> loc, const char* msg) {
     ODesc d;
-    loc->Describe(&d);
+    loc->Loc()->Describe(&d);
 
     reporter->Warning("%s: %s", d.Description(), msg);
 }
